package Bundle::Locale::CLDR::Oceania;

use version;

our $VERSION = version->declare('v0.34.1');

=head1 NAME Bundle::Locale::CLDR::Oceania

=head1 CONTENTS

Bundle::Locale::CLDR::Melanesia 0.34.1
Bundle::Locale::CLDR::Polynesia 0.34.1
Bundle::Locale::CLDR::Australasia 0.34.1
Bundle::Locale::CLDR::Outlyingoceania 0.34.1
Bundle::Locale::CLDR::Micronesianregion 0.34.1

=cut

1;

